from collective.anonymousview.tests.base import TestCase
from zope.testing import doctestunit
from Testing import ZopeTestCase as ztc
import doctest
import unittest
from Products.Five.testbrowser import Browser

def test_suite():
    """This sets up a test suite that actually runs the tests in collective.anonymousview_integration.txt"""
    return unittest.TestSuite([
        ztc.FunctionalDocFileSuite(
            'tests/anonymousview_integration.txt', package='collective.anonymousview',
            test_class=TestCase),
        ])




"""Test setup for integration and functional tests."""

from Products.Five import zcml
from Products.Five import fiveconfigure

from Products.PloneTestCase import PloneTestCase as ptc
from Products.PloneTestCase.setup import portal_owner, default_password
from Products.PloneTestCase.layer import onsetup

from Testing import ZopeTestCase as ztc
from Products.Five.testbrowser import Browser

import os

@onsetup
def setup_product():
    """Set up the package and its dependencies."""
    
    fiveconfigure.debug_mode = True
    import collective.anonymousview 
    zcml.load_config('configure.zcml', collective.anonymousview)
    fiveconfigure.debug_mode = False
    # We need to have a zserver to test the browerview
    ztc.utils.startZServer()
    
setup_product()
ptc.setupPloneSite(products=['collective.anonymousview'])

class TestCase(ptc.PloneTestCase):
    """We use this base class for all the tests in this package. If necessary,
    we can put common utility or setup code in here. This applies to unit 
    test cases.
    """
    def __init__(self):
        self.portal_owner = portal_owner
        self.default_password = default_password
        
    def getLoggedInBrowser(self):
        """Returns a zope browser object"""
        browser = Browser()
        browser.open(self.portal.absolute_url())
        browser.getControl(name='__ac_name').value = self.portal_owner
        browser.getControl(name='__ac_password').value = self.default_password
        browser.getControl(name='submit').click()
        return browser

    



import transaction
from Products.CMFCore.utils import getToolByName

PRODUCT_DEPENDENCIES = ()
                        
EXTENSION_PROFILES = ('collective.anonymousview:default',)

def install(self, reinstall=False):
    """Install a set of products (which themselves may either use Install.py
    or GenericSetup extension profiles for their configuration) and then
    install a set of extension profiles.
    
    One of the extension profiles we install is that of this product. This
    works because an Install.py installation script (such as this one) takes
    precedence over extension profiles for the same product in 
    portal_quickinstaller. 
    
    We do this because it is not possible to install other products during
    the execution of an extension profile (i.e. we cannot do this during
    the importVarious step for this profile).
    """
    
    portal_quickinstaller = getToolByName(self, 'portal_quickinstaller')
    portal_setup = getToolByName(self, 'portal_setup')

    for product in PRODUCT_DEPENDENCIES:
        if reinstall and portal_quickinstaller.isProductInstalled(product):
            portal_quickinstaller.reinstallProducts([product])
            transaction.savepoint()
        elif not portal_quickinstaller.isProductInstalled(product):
            portal_quickinstaller.installProduct(product)
            transaction.savepoint()
    
    for extension_id in EXTENSION_PROFILES:
        portal_setup.runAllImportStepsFromProfile('profile-%s' % extension_id, purge_old=False)
        product_name = extension_id.split(':')[0]
        portal_quickinstaller.notifyInstalled(product_name)
        transaction.savepoint()


from zope.interface import implements
from Products.Five.browser import BrowserView
from interfaces import IAnonymousView
from zope.app import zapi
import urllib2

class AnonymousView(BrowserView):
	implements(IAnonymousView)
	
	def __call__(self):
		url = zapi.absoluteURL(self.context, self.request)
		response = urllib2.urlopen(url)
		return response.read()